function grav
%2005 Ersan Turkoglu
%224 Lab2 gravity modelling
%Calls forwardit.m (prepared by Unsworth 200?)
%This program calculates gravity anomaly of a 2 dimensional
%shape. This code is implemented to read "alberta_bc_1.txt" and 
%"ImpactCrater.txt" files.
%for help or bug report contact ET by 
%e-mail:eturk@Phys.UAlberta.CA
root='ImpactCrater';
brden=2000 ;
bden =1000;
np   =4;

axymin=-3;

forwardit(root,axymin)

for trial=1:100
ilk=menu('Control Menu','Load Impact Crater Data','Load abc model-1','Load abc model-2','JPG&EXIT');

if ilk==2
    root='alberta_bc_1';
    axymin=-60;
    forwardit(root,axymin);
elseif ilk==3
    root='alberta_bc_2';
    axymin=-60;
    forwardit(root,axymin);
elseif ilk==1
    root='ImpactCrater';
    axymin=-3;
    forwardit(root,axymin);
elseif ilk==4
    trial=100;
end
    if trial==100
        print( 1, '-djpeg', root)
        close all
        break
    end

end  %ends main loop
%------------------------------------------------------------
function forwardit(root,axymin)
% Computes g_z and dg_z/dz for  a polygon using Talwani
% line integral
% Need to check direction of loop definition (clockwise!)

% This version reads in density as well from file and can
% model multiple polygons
% Load density model
% Number of polygons = Npolygons
% ith polygon has density rho(i) and nvertex(i) corners
root
if root=='alberta_bc_2'
    ax1=[0 1450 axymin 0];
    ax2=[0 1450 -150 50];
elseif root=='alberta_bc_1'
    ax1=[0 1450 axymin 0];
    ax2=[0 1450 -150 50];
else
    ax1=[-5 125 axymin 0];
    ax2=[-5 125 -30 0];
end

fid =fopen([root,'_mod.txt'],'r');
background_density=fscanf(fid,'%f',1);
npolygons=fscanf(fid,'%i',1);
for ipoly=1:npolygons
   rho(ipoly) = fscanf(fid,'%f',1);
   drho(ipoly) = rho(ipoly)-background_density;
   nvertex(ipoly) = fscanf(fid,'%f',1);
   for iv=1:nvertex(ipoly)
     xz=fscanf(fid,'%f',2);
     xp(ipoly,iv)=xz(1)*1000;
     zp(ipoly,iv)=xz(2)*1000;
   end
end
% Read in gravity data
fid =fopen([root,'.txt'],'r');
alln=fscanf(fid, '%f');
fclose(fid);
ndata = length(alln)/3;
fid =fopen([root,'.txt'],'r');
for i =1:ndata
  data = fscanf(fid,'%f',3);
  x_data(i)  = data(1);
  g_data(i)  = data(2);
  g_error(i) = data(3);
end
% Find maximum values of offset and Bouguer data
  xmax = 1.1*max(x_data);
  xmin = 1.1*min(x_data);
  ndata = length(x_data);

  g_max=0.9*max(g_data);
  g_min=1.1*min(g_data);

% Vector with colour flags for polygons
col=['g','b','c','r','m','y'];
G = 6.67e-11;
% No. of integration points on each polygon side
npts =60;
for i=1:ndata
  xobs(i) = x_data(i); 
end
nx =length(xobs);
zmin = 1.2*max(max(zp));
npoints =length(xp);

% start loop over gravity measurement points
for ix=1:nx   
% Loop over polygons   
  for ipoly=1:npolygons
  % Loop over each side of polygon
    for iv =1:nvertex(ipoly)-1   
      dz = (zp(ipoly,iv+1)-zp(ipoly,iv))/npts;
      dx = (xp(ipoly,iv+1)-xp(ipoly,iv))/npts;
      side(ipoly,iv) = 0.0;
  % Integrate over side with npts steps   
      for j = 1:npts
        zint = zp(ipoly,iv)+j*dz;
        if abs(zint) < 0.000001
           zint = 0.000001;
        end
        xint = xp(ipoly,iv)+j*dx;
        theta = atan(abs(xint-xobs(ix))/zint);
        if xobs(ix)>= xint
          theta = -theta;
        end
        side(ipoly,iv) = side(ipoly,iv) + theta*dz;
      end
    end   
  
    % Sum over the different sides of the polygon. This is needed since polygons
    % can have different numbers of sides. Beware earlier versions of this code.
    dg(ipoly,ix) = 0.;
    for iv=1:nvertex(ipoly)-1
      dg(ipoly,ix) = dg(ipoly,ix)-1.0e5*2*G*drho(ipoly)*side(ipoly,iv);
    end   
  end 
end

% Sum over contributions from different polygons (dg) to get Bouguer anomaly (gb)
for i=1:ndata
   gb(i)=0.0;
   for ipoly=1:npolygons
      gb(i)=gb(i)+dg(ipoly,i);
   end
end   

% Plot density model
subplot(211);
for ipoly=1:npolygons
    fill(0.001*xp(ipoly,:),-0.001*zp(ipoly,:),col(ipoly)); hold on
    if root=='alberta_bc_2'
        plot(380,0,'r^','markersize',10); plot(575,0,'r^','markersize',10); plot(1100,0,'r^','markersize',10);
    elseif root=='alberta_bc_1'
        plot(380,0,'r^','markersize',10); plot(575,0,'r^','markersize',10); plot(1100,0,'r^','markersize',10);
    end
end   
axis(ax1);
%if root=='alberta_bc_2'
%    hold on; plot(26.5,0,'*'); hold off
%end
xlabel('Distance along the profile (km)'); ylabel('Depth (km)'); title(['Earth Density Model'])
hold off;
% Bouguer anomaly 
subplot(212)
if root=='alberta_bc_2'
    plot(0.001*xobs,gb-730,'-');
    hold on
    plot(0.001*x_data,g_data-730,'*');
elseif root=='alberta_bc_1'
    plot(0.001*xobs,gb-730,'-');
    hold on
    plot(0.001*x_data,g_data-730,'*');
else
    plot(0.001*xobs,gb,'-');
    hold on
    plot(0.001*x_data,g_data,'*');
end
axis(ax2);
xlabel('Distance along the profile (km)'); ylabel('Bougeur Anomaly (miligals)'); title('Observed Data & Model Fit')
legend('Calculated Model','Observed Data',0)
hold off